# -*- coding: utf-8 -*-
"""
sassets
=======

sassets provides high-level functions to handle with assets.
"""

__version__ = '1.0'

import os

from .helpers import calculate_file_hash, rename_asset


def rename_assets_and_build_map(asset_paths):
    """Rename all assets listed in `asset_paths` to include a hash based on
    their content. Returns a dictionary where the key is the old filename
    (before renaming) and the value is the new filename (after renaming).

    .. note:: The strings in keys and values of the returned dictionary only
              refers to the filename, not the whole path (see example below).

    Example::

        asset_paths = ['/tmp/main.css', '/home/u/project/lib.js']
        asset_map = rename_assets_and_build_map(asset_paths)

        # Files will be renamed:
        #   before: /tmp/main.css
        #   after:  /tmp/main.e69696ebb861873477a2b080fd5b7278.css
        #
        #   before: /home/u/project/lib.js
        #   after:  /home/u/project/lib.72baa35d04f87761301b64ce32489386.js

        # Return value (asset_map) will be:
        {
            'main.css': 'main.e69696ebb861873477a2b080fd5b7278.css',
            'lib.js': 'lib.72baa35d04f87761301b64ce32489386.js'
        }

    :param asset_paths: list of paths to the asssets.
    """
    map_filename_hash = {}
    for filepath in asset_paths:
        hash_value = calculate_file_hash(filepath)
        new_filename = rename_asset(filepath, hash_value)
        old_filename = os.path.basename(filepath)
        map_filename_hash[old_filename] = new_filename
    return map_filename_hash
